package sgc.portal.cw.cw0303.persistence;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cw.cw0303.dto.CW03030001USearch;
import sgc.portal.cw.cw0303.model.CW03030001U;
import sgc.portal.cw.cw0304.model.CW03040001U;

import java.util.List;
import java.util.Map;

@Mapper
public interface CW03030001UMapper {
	
	//위임고충 처리 조회
	List<EasyHashMap<String, Object>> selectProblemMandateList(CW03030001USearch search);
	
	int selectCount2(CW03030001U cW03030001U);
	
	String selectUserEmailList(CW03030001U cW03030001U);
	
	//위임고충 처리
	void updateProblemMandate1(CW03030001U cW03030001U);
	void updateProblemMandate2(CW03030001U cW03030001U);
	void updateProblemMandate3(CW03030001U cW03030001U);
	void updateProblemMandate4(CW03030001U cW03030001U);
	void insertProblemMandate(CW03030001U cW03030001U);
		
	//접수
	void updateProblemMandateReceipt(CW03030001U cW03030001U);
}
